---
date: 2016-03-09T00:11:02+01:00
title: About the Archives Unleashed Project
weight: 10
---

![Network diagram](/images/label-hairball.png)

Archives Unleashed aims to make petabytes of historical internet content accessible to scholars and others interested in researching the recent past. Supported by a grant from the [Andrew W. Mellon Foundation](https://mellon.org/), we are developing web archive search and data analysis tools to enable scholars, librarians and archivists to access, share, and investigate recent history since the early days of the World Wide Web.

Growing out of a series of datathons held at the <a href="http://archivesunleashed.ca/">University of Toronto</a>, <a href="http://archivesunleashed.com/">Library of Congress</a>, <a href="http://archivesunleashed.com/">Internet Archive</a>, and the <a href="http://archivesunleashed.com/">British Library</a>, our team recognized the need for better analytics tools, community infrastructure, and accessible web archival interfaces.

The three-year Archives Unleashed project has three major thrusts: First, the project will build a [software toolkit](/aut) that applies modern big data analytics infrastructure to scholarly analysis of web archives. Second, the toolkit will be deployed in a [cloud-based environment](/cloud) that will provide a one-stop portal for scholars to ingest their collections and execute a number of analyses with the click of a mouse. Finally, [datathons](/events) — will build a cohesive and sustainable user community by bringing the core project team members together with librarians, archivists, and other interested researchers.

## Project Team
|                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
|-------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| ![Milligan](/images/Milligan.png)**Principal Investigator**| **[Ian Milligan](https://ianmilligan.ca/)** is associate professor of history at the University of Waterloo. Since 2012, he has been engaged in building tools, infrastructure, and frameworks to facilitate the historical use of web archives. In 2016, he was awarded the Canadian Society for Digital Humanities’ Outstanding Early Career Award.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| ![Ruest](/images/Ruest.jpeg)**Co-Principal Investigator**| **[Nick Ruest](http://ruebot.net/)** is the Digital Assets Librarian at York University. He is Co-PI of both the WALK project and the Social Sciences and Humanities Research Council of Canada Insight Grant with Milligan. Ruest is dedicated to building systems to ensure that valuable historical and cultural materials are preserved and made universally accessible. He has been Release Manager for five Islandora releases and four Fedora releases, both of which are open source digital asset management systems. He was previously the Project Director for Islandora CLAW and leader of the Fedora Import-Export Initiative.                                                                                                                                                                                                                                              |
| ![Lin](/images/Lin.jpg)**Co-Principal Investigator**| **[Jimmy Lin](https://cs.uwaterloo.ca/~jimmylin/)** is the David R. Cheriton Chair in the David R. Cheriton School of Computer Science at the University of Waterloo. His research aims to build tools that help users make sense of large amounts of data. He works at the intersection of information retrieval, natural language processing, and databases, with a focus on large-scale distributed algorithms and infrastructure for data analytics.                                                                                                                                                                                                                                                                                                                                                                                                                                |
| ![Fritz](/images/Fritz.jpg)**Project Manager**| **[Samantha Fritz](https://uwaterloo.ca/web-archive-group/people-profiles/samantha-fritz)** is the project manager for the Archives Unleashed Team. She is an information management professional with a passion for open access, information literacy education, and helping people connect with and make sense of data. After completing her MLIS, Samantha has engaged with researchers who assess the social impact of para sport on perceptions of (dis)ability, as well as intervention models for privacy education among young adults. She is driven to support information and resource dissemination to positively transform the way researchers view, experience, interpret and share information and knowledge. She has worked with organizations such as Ryerson University’s Social Media Lab, the Islandora Foundation, and Dalhousie University Libraries on digitization and data visualization projects. |
| ![Deschamps](/images/Deschamps.jpg)**Postdoctoral Fellow**| **[Ryan Deschamps](https://uwaterloo.ca/web-archive-group/people-profiles/ryan-deschamps)** is a postdoctoral fellow in the University of Waterloo’s Department of History, working under Milligan. He completed his dissertation at the Johnson Shoyama Graduate School of Public Policy (University of Regina) studying the role of social media on policy agendas. His post-doctoral research focuses on the influence of digital information on the interpretation of Canadian historical events. Ryan’s position is funded by the Social Sciences and Humanities Research Council and the David R. Cheriton Chair at the David R. Cheriton School of Computer Science.                                                                                                                                                                                                                                                |

## Advisory Board
|                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        |
|--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| **[Jefferson Bailey](http://www.jeffersonbailey.com)** is Director of Web Archiving at Internet Archive. Jefferson joined Internet Archive in Summer 2014 and manages Internet Archive’s web archiving services, including Archive-It, used by over 450 institutions to preserve the web. He also oversees contract domain-scale web archiving services for national libraries and archives around the world, including Library of Congress, NARA, and foreign national libraries. He works closely with partner institutions on technology development, web data research services, educational partnerships, and other programs. He is PI on multiple grants focused on systems interoperability, data-driven research use of web archives, and digital preservation. Prior to Internet Archive, he worked on strategic initiatives, digital collections, and digital preservation at institutions such as Metropolitan New York Library Council, Library of Congress, Brooklyn Public Library, and Frick Art Reference Library and has worked in the archives at NARA, NASA, and Atlantic Records. He is currently Vice Chair of the International Internet Preservation Consortium. He has an MLIS in Archives from University of Pittsburgh and a BA in English from Oberlin College.                                                                                                                                                   |
| **[Nathalie Casemajor](http://www.ucs.inrs.ca/nathalie-casemajor)** is an Assistant Professor in the Urbanisation Culture Société Research Centre at INRS (Institut national de la recherche scientifique, Montreal). Her work focuses on culture, territories and communities as well as digital culture. She was previously an Assistant Professor at the Université du Québec en Outaouais, a Postdoctoral Fellow at McGill University (Department of Art History and Communications Studies) as well as a Visiting Scholar at the New York University (Department of Media, Culture and Communication).                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
| **[Robert H. McDonald](https://www.colorado.edu/libraries/robert-mcdonald)** is the Dean of Libraries at University of Colorado Boulder. His research interests include technology management and integration of lean and agile frameworks, data preservation, learning eco-systems, data cyberinfrastructure, and big data analytics. Robert frequently presents and writes on a variety of topics, and was editor of the E-Content column for EDUCAUSE Review in 2016 – 2017. He is active professionally with a number of national and international organizations and conferences, serving on the HathiTrust Program Steering committee, as the chair for the Digital Preservation Network Heavy Users committee, and as general co-chair for the ACM/IEEE Joint Conference on Digital Libraries in 2013 and 2017. |
| **[Matthew Weber](https://apps.cla.umn.edu/directory/profiles/msw?search_results_referer_url=%2Fdirectory%2Fresults%3Fpage%3D28%26q%3DPopular%2BCulture)** is an Associate Professor in the Hubbard School of Journalism and Mass Communication at the University of Minnesota and is the Cowles Endowed Fellow of Media Management. He is Principal Investigator on a National Science Foundation grant that aims to develop new methods and new collaborations for conducting research utilizing Internet Archive data. Weber’s grant works with more than 50 TB of archived Internet data, testing and publishing scripts for transforming archived Internet data into formats that are compatible with existing social science computing packages such as R and SPSS. Weber has related funding from the Democracy Fund, Institute of Library and Information Science and the William T. Grant Foundation.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
| **[Michele Weigle](https://www.odu.edu/directory/people/m/mweigle)** is a Professor of Computer Science at Old Dominion University. Her research interests include digital preservation, web science, information visualization, and mobile networking. Since 2012, she has been PI or Co-PI on over $2M in funding for research related to web archiving from NSF, NEH, IMLS, and the Andrew W. Mellon Foundation. Dr. Weigle received her PhD in computer science from the University of North Carolina at Chapel Hill in 2003.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
| **[Nicholas Worby](https://onesearch.library.utoronto.ca/library-staff/nich-worby)** is the Government Information and Statistics Librarian as well as the Web Archives Program Coordinator at the University of Toronto. In addition to providing research and instruction support for government information and statistics, he oversees collection development, production crawls and researcher outreach for web archive collections.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |

## Code of Conduct

### Our Pledge

* The Archives Unleashed Project believes in supporting an open, inclusive, and
 diverse community which respects the experience, expertise, and knowledge of
all community members.
* The Archives Unleashed community is dedicated to providing a harassment-free
 experience for everyone, and welcomes individuals regardless age, body size,
disability, ethnicity, gender identity and expression, level of experience,
nationality, personal appearance, race, religion, or sexual identity and
orientation.
* To foster respectful collaborations this code of conduct applies to all
Archives Unleashed spaces, includes, but is not limited to, GitHub, Slack,
Medium, social media platforms and meeting spaces, both online and off.
* Anyone who violates this code of conduct may be sanctioned or expelled from
 these spaces at the discretion of the Archives Unleashed Project Team.

### Our Standards

Examples of behavior that contributes to creating a positive environment
include:

* Using welcoming and inclusive language
* Being respectful of differing viewpoints and experiences
* Gracefully accepting constructive criticism
* Focusing on what is best for the community
* Showing empathy towards other community members

Examples of unacceptable behavior by participants include:

* The use of sexualized language or imagery and unwelcome sexual attention or
advances
* Trolling, insulting/derogatory comments, and personal or political attacks
* Public or private harassment
* Publishing others' private information, such as a physical or electronic
  address, without explicit permission
* Other conduct which could reasonably be considered inappropriate in a
  professional setting

### Our Responsibilities

Project maintainers are responsible for clarifying the standards of acceptable
behavior and are expected to take appropriate and fair corrective action in
response to any instances of unacceptable behavior.

Project maintainers have the right and responsibility to remove, edit, or
reject comments, commits, code, wiki edits, issues, and other contributions
that are not aligned to this Code of Conduct, or to ban temporarily or
permanently any contributor for other behaviors that they deem inappropriate,
threatening, offensive, or harmful.

### Scope

This Code of Conduct applies both within project spaces and in public spaces
when an individual is representing the project or its community. Examples of
representing a project or community include using an official project e-mail
address, posting via an official social media account, or acting as an appointed
representative at an online or offline event. Representation of a project may be
further defined and clarified by project maintainers.

### Enforcement

Instances of abusive, harassing, or otherwise unacceptable behavior may be
reported by contacting the project team at archivesunleashed@gmail.com. All
complaints will be reviewed and investigated and will result in a response that
is deemed necessary and appropriate to the circumstances. The project team is
obligated to maintain confidentiality with regard to the reporter of an incident.
Further details of specific enforcement policies may be posted separately.

Project maintainers who do not follow or enforce the Code of Conduct in good
faith may face temporary or permanent repercussions as determined by other
members of the project's leadership.

### Attribution

This Code of Conduct is adapted from the [Contributor Covenant][homepage], version 1.4,
available at [http://contributor-covenant.org/version/1/4][version]

[homepage]: http://contributor-covenant.org
[version]: http://contributor-covenant.org/version/1/4/

## Funding

This work is primarily supported by the [Andrew W. Mellon Foundation](https://mellon.org/). Other financial and in-kind support comes from the [Social Sciences and Humanities Research Council](http://www.sshrc-crsh.gc.ca), [Compute Canada](https://www.computecanada.ca), the [Ontario Ministry of Research, Innovation, and Science](https://www.ontario.ca/page/ministry-research-innovation-and-science), [York University Libraries](https://www.library.yorku.ca/web/), [Start Smart Labs](http://www.startsmartlabs.com), and the [Faculty of Arts](https://uwaterloo.ca/arts/) and [David R. Cheriton School of Computer Science](https://cs.uwaterloo.ca) at the [University of Waterloo](https://uwaterloo.ca).
